*--------------------------------------------------------------------------
* Model generated by Motega software: 
*
*              Modeling Of Tubes Employing Genetic Algorithms
*
* Models contain 1G resistors from all nodes to earth in order to avoid
* floating nodes. Triode and tetrode/pentode models contain a diode for
* simulating grid current.
*
* Non-commercial use is permitted, but at your own risk... This model
* is provided "as is", without warranty of any kind. In no event shall
* Jeroen Boschma be liable for any claim, damages or other liability,
* whether in an action of contract, tort or otherwise, arising from,
* out of or in connection with the tube model or the use or other
* dealings in the tube model.
*
*
*                         Copyright Jeroen Boschma
*                              www.boschma.com
*
* Motega V 1.0, 25-May-2010 16:25:22
*--------------------------------------------------------------------------



*--------------------------------------------------------------------------
* Generic tetrode/pentode model
*--------------------------------------------------------------------------

.SUBCKT TubePentode  A  Gr2  Gr1  K
+ PARAMS: ua=1 ug2=1 xa=1 xg2=1 qa=1 qg2=1 kg1=1 kg2=1 kvba=1 kvbg2=1 ce=1
*
* Resistors in order to avoid floating nodes
*
R1   A    0   1G
R2   Gr2  0   1G
R3   Gr1  0   1G
R4   K    0   1G
*
* Intermediate expressions which simplify the current calculation
*
RE1  1    0   1G
E1   1    0   VALUE={xa + ce*PWR(V(A,K),2)}
RE2  2    0   1G
E2   2    0   VALUE={V(Gr2,K)*LOG(1 + EXP(qa*(1/ua + V(Gr1,K)/V(Gr2,K))))/qa}
RE3  3    0   1G
E3   3    0   VALUE={V(Gr2,K)*LOG(1 + EXP(qg2*(1/ug2 + V(Gr1,K)/V(Gr2,K))))/qg2}
*
* Actual current calculation
*
G1   A    K   VALUE={(PWR(V(2),V(1)) + PWRS(V(2),V(1)))*ATAN(V(A,K)/kvba)/kg1}
G2   Gr2  K   VALUE={(PWR(V(3),V(1)) + PWRS(V(3),V(1)))*ATAN(V(A,K)/kvbg2)/kg2}
*
* Grid current modeling
*
RG   Gr1  4   1K
D1   4    K   DX
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N)
*
* Close the model
*
.ENDS


*--------------------------------------------------------------------------
* Specialized tube model
*
*    Type           : 6J51P
*    Description    : Pentode High Mu
*    Direct heated  : no
*    Screen present : no
*--------------------------------------------------------------------------

.SUBCKT 6J51P    A  Gr2  Gr1  K 
*
* Resistors in order to avoid floating nodes
*
* RF   F    0   1G
*
* Link to the generic model
*
XV1     A         Gr2      Gr1      K       TubePentode
+ PARAMS: ua=4.008K ug2=1.864K xa=1.694 xg2=1.142 qa=137.653 qg2=171.534
+ kg1=19.543 kg2=48.104 kvba=34.582 kvbg2=2.538M ce=81.468N
*
* Capacitances
*
C1    A        K        3.300P   ; Cak
C2    Gr1      K        11.500P   ; Cg1k
C3    A        Gr1      0.005P   ; Cag1
*
* Close the model
*
.ENDS


*--------------------------------------------------------------------------
* End of file
*--------------------------------------------------------------------------
